@@ -84,7 +84,7 @@ Readonly my $DIGEST_RE                  => qr/^[a-f0-9]{40}$|^[a-f0-9]{64}$|^[a-
 Readonly my $ENGINE_TYPE_RE             => qr/^(?:mysql|postgresql|sqlite)$/i;
 Readonly my $IPADDR_RE                  => qr/^$|$IPV4_RE|$IPV6_RE/;
 Readonly my $JSONRPC_METHOD_RE          => qr/^[a-z0-9_-]*$/i;
-Readonly my $LANGUAGE_RE                => qr/^[a-z]{2}(_[A-Z]{2})?$/;
+Readonly my $LANGUAGE_RE                => qr/^[a-z]{2}$/;
 Readonly my $LDH_DOMAIN_RE1             => qr{^[a-z0-9_./-]{1,253}[.]?$}i;
 Readonly my $LDH_DOMAIN_RE2             => qr{^(?:[.]|[^.]{1,63}(?:[.][^.]{1,63})*[.]?)$};
 Readonly my $LOCALE_TAG_RE              => qr/^[a-z]{2}_[A-Z]{2}$/;
@@ -270,7 +270,7 @@ sub formats {
 
 =head2 check_domain(%value)
 
-Validates a L<domain name|https://github.com/zonemaster/zonemaster-backend/blob/master/docs/API.md#domain-name>.
+Validates a L<domain name|https://github.com/zonemaster/zonemaster/blob/master/docs/public/using/backend/rpcapi-reference.md#domain-name>.
 
 =cut
 
@@ -314,13 +314,13 @@ sub check_domain {
 
 =head2 check_language_tag($value, %locales)
 
-Validates a L<https://github.com/zonemaster/zonemaster-backend/blob/master/docs/API.md#language-tag>.
+Validates a L<https://github.com/zonemaster/zonemaster/blob/master/docs/public/using/backend/rpcapi-reference.md#language-tag>.
 
 =over
 
 =item %locales
 
-Hash of accepted locales, using the same structure than the hash returned by L<PUBLIC_PROFILES|Zonemaster::Bakend::Config/PUBLIC_PROFILES>.
+A hash of configured locales, as returned by L<Zonemaster::Backend::Config::LANGUAGE_locale>.
 
 =back
 
@@ -334,26 +334,16 @@ sub check_language_tag {
     if ( $language !~ $LANGUAGE_RE ) {
         return N__ 'Invalid language tag format';
     }
+    elsif ( !exists $locales{$language} ) {
+        return N__ "Unkown language string";
+    }
 
-    if ( length $language == 2 ) {
-        if ( !exists $locales{$language} ) {
-            return N__ "Unkown language string";
-        }
-        elsif ( scalar keys %{ $locales{$language} } > 1 ) {
-            return N__ "Language string not unique";
-        }
-    }
-    else {
-        if ( !exists $locales{substr $language, 0, 2}{$language} ) {
-            return N__ "Unkown language string";
-        }
-    }
     return undef;
 }
 
 =head2 check_ip($value)
 
-Validates an L<IP address|https://github.com/zonemaster/zonemaster-backend/blob/master/docs/API.md#ip-address>.
+Validates an L<IP address|https://github.com/zonemaster/zonemaster/blob/master/docs/public/using/backend/rpcapi-reference.md#ip-address>.
 
 =cut
 
@@ -368,13 +358,13 @@ sub check_ip {
 
 =head2 check_profile($value, %profiles)
 
-Validates a L<profile name|https://github.com/zonemaster/zonemaster-backend/blob/master/docs/API.md#profile-name>.
+Validates a L<profile name|https://github.com/zonemaster/zonemaster/blob/master/docs/public/using/backend/rpcapi-reference.md#profile-name>.
 
 =over
 
 =item %profiles
 
-Hash of accepted profiles, using the same structure than the hash returned by L<LANGUAGE_locale|Zonemaster::Bakend::Config/LANGUAGE_locale>.
+A hash of configured profiles, as returned by L<Zonemaster::Backend::Config::PUBLIC_PROFILES>.
 
 =back
 
